@@ -18,6 +18,11 @@ sub parse_journalmail
     $Parser->extract_nested_messages(0);
     my $Entity = $Parser->parse_data($journal_msg);
 
+    # check journaling header
+    unless (defined($Entity->head->get('X-MS-Journal-Report'))) {
+        die "Email is not a MS-Journal-Report\n";
+    }
+
     # journal mail structure of Exchange 2007 / 2010
     #
     # layer | type                      |
